{
    "$graph": [
        {
            "class": "CommandLineTool",
            "label": "qiime2: Perform de novo multiple sequence alignment using MAFFT",
            "hints": [
                {
                    "class": "DockerRequirement",
                    "dockerPull": "qiime2/core:2018.4",
                    "id": "#qiime2-docker-hint.yml",
                    "name": "#qiime2-docker-hint.yml"
                }
            ],
            "inputs": [
                {
                    "type": "string",
                    "label": "resulting aligned sequences filename",
                    "inputBinding": {
                        "prefix": "--o-alignment"
                    },
                    "id": "#alignment-mafft.cwl/alignment_filename"
                },
                {
                    "type": "File",
                    "label": "sequences to be aligned",
                    "inputBinding": {
                        "prefix": "--i-sequences"
                    },
                    "id": "#alignment-mafft.cwl/sequences"
                }
            ],
            "baseCommand": [
                "qiime",
                "alignment",
                "mafft"
            ],
            "id": "#alignment-mafft.cwl",
            "outputs": [
                {
                    "type": "File",
                    "outputBinding": {
                        "glob": "$(inputs.alignment_filename)"
                    },
                    "id": "#alignment-mafft.cwl/alignment"
                }
            ]
        },
        {
            "class": "CommandLineTool",
            "label": "qiime2: Mask unconserved and highly gapped columns from an alignment",
            "hints": [
                {
                    "$import": "#qiime2-docker-hint.yml"
                }
            ],
            "inputs": [
                {
                    "type": "File",
                    "label": "alignment to be masked",
                    "inputBinding": {
                        "prefix": "--i-alignment"
                    },
                    "id": "#alignment-mask.cwl/alignment"
                },
                {
                    "type": "string",
                    "label": "masked alignment filename",
                    "inputBinding": {
                        "prefix": "--o-masked-alignment"
                    },
                    "id": "#alignment-mask.cwl/masked_aligned_rep_seqs_filename"
                }
            ],
            "outputs": [
                {
                    "type": "File",
                    "outputBinding": {
                        "glob": "$(inputs.masked_aligned_rep_seqs_filename)"
                    },
                    "id": "#alignment-mask.cwl/masked_aligned_rep_seqs"
                }
            ],
            "baseCommand": [
                "qiime",
                "alignment",
                "mask"
            ],
            "id": "#alignment-mask.cwl"
        },
        {
            "class": "CommandLineTool",
            "label": "qiime2: Construct a phylogenetic tree with FastTree",
            "hints": [
                {
                    "$import": "#qiime2-docker-hint.yml"
                }
            ],
            "inputs": [
                {
                    "type": "File",
                    "label": "aligned sequences to be used for phylogenetic reconstruction",
                    "inputBinding": {
                        "prefix": "--i-alignment"
                    },
                    "id": "#phylogeny-fasttree.cwl/alignment"
                },
                {
                    "type": "string",
                    "label": "resulting phylogenetic tree filename",
                    "inputBinding": {
                        "prefix": "--o-tree"
                    },
                    "id": "#phylogeny-fasttree.cwl/tree_filename"
                }
            ],
            "outputs": [
                {
                    "type": "File",
                    "outputBinding": {
                        "glob": "$(inputs.tree_filename)"
                    },
                    "id": "#phylogeny-fasttree.cwl/unrooted_tree"
                }
            ],
            "baseCommand": [
                "qiime",
                "phylogeny",
                "fasttree"
            ],
            "id": "#phylogeny-fasttree.cwl"
        },
        {
            "class": "CommandLineTool",
            "label": "qiime2: Midpoint root an unrooted phylogenetic tree",
            "hints": [
                {
                    "$import": "#qiime2-docker-hint.yml"
                }
            ],
            "inputs": [
                {
                    "type": "string",
                    "label": "rooted phylogenetic tree",
                    "inputBinding": {
                        "prefix": "--o-rooted-tree"
                    },
                    "id": "#phylogeny-midpoint-root.cwl/rooted_tree_filename"
                },
                {
                    "type": "File",
                    "label": "phylogenetic tree to be rooted",
                    "inputBinding": {
                        "prefix": "--i-tree"
                    },
                    "id": "#phylogeny-midpoint-root.cwl/tree"
                }
            ],
            "outputs": [
                {
                    "type": "File",
                    "outputBinding": {
                        "glob": "$(inputs.rooted_tree_filename)"
                    },
                    "id": "#phylogeny-midpoint-root.cwl/rooted_tree"
                }
            ],
            "baseCommand": [
                "qiime",
                "phylogeny",
                "midpoint-root"
            ],
            "id": "#phylogeny-midpoint-root.cwl"
        },
        {
            "class": "Workflow",
            "requirements": [
                {
                    "class": "SubworkflowFeatureRequirement"
                }
            ],
            "label": "qiime2 create phylogenetic tree",
            "doc": "Generate a tree for phylogenetic diversity analyses from https://docs.qiime2.org/2018.4/tutorials/moving-pictures/",
            "inputs": [
                {
                    "type": "string",
                    "default": "aligned-rep-seqs.qza",
                    "id": "#main/aligned_rep_seqs_filename"
                },
                {
                    "type": "string",
                    "default": "masked-aligned-rep-seqs.qza",
                    "id": "#main/masked_aligned_rep_seqs_filename"
                },
                {
                    "type": "File",
                    "id": "#main/representative_sequences"
                },
                {
                    "type": "string",
                    "default": "rooted-tree.qza",
                    "id": "#main/rooted_tree_filename"
                },
                {
                    "type": "string",
                    "default": "unrooted-tree.qza",
                    "id": "#main/unrooted_tree_filename"
                }
            ],
            "outputs": [
                {
                    "type": "File",
                    "outputSource": "#main/align_representative_sequences/alignment",
                    "id": "#main/aligned_representative_sequences"
                },
                {
                    "type": "File",
                    "outputSource": "#main/mask_representative_sequences/masked_aligned_rep_seqs",
                    "id": "#main/masked_representative_sequences"
                },
                {
                    "type": "File",
                    "outputSource": "#main/root_tree/rooted_tree",
                    "id": "#main/rooted_tree"
                },
                {
                    "type": "File",
                    "outputSource": "#main/create_tree_from_alignment/unrooted_tree",
                    "id": "#main/unrooted_tree"
                }
            ],
            "steps": [
                {
                    "run": "#alignment-mafft.cwl",
                    "in": [
                        {
                            "source": "#main/aligned_rep_seqs_filename",
                            "id": "#main/align_representative_sequences/alignment_filename"
                        },
                        {
                            "source": "#main/representative_sequences",
                            "id": "#main/align_representative_sequences/sequences"
                        }
                    ],
                    "out": [
                        "#main/align_representative_sequences/alignment"
                    ],
                    "id": "#main/align_representative_sequences"
                },
                {
                    "run": "#phylogeny-fasttree.cwl",
                    "in": [
                        {
                            "source": "#main/mask_representative_sequences/masked_aligned_rep_seqs",
                            "id": "#main/create_tree_from_alignment/alignment"
                        },
                        {
                            "source": "#main/unrooted_tree_filename",
                            "id": "#main/create_tree_from_alignment/tree_filename"
                        }
                    ],
                    "out": [
                        "#main/create_tree_from_alignment/unrooted_tree"
                    ],
                    "id": "#main/create_tree_from_alignment"
                },
                {
                    "run": "#alignment-mask.cwl",
                    "in": [
                        {
                            "source": "#main/align_representative_sequences/alignment",
                            "id": "#main/mask_representative_sequences/alignment"
                        },
                        {
                            "source": "#main/masked_aligned_rep_seqs_filename",
                            "id": "#main/mask_representative_sequences/masked_aligned_rep_seqs_filename"
                        }
                    ],
                    "out": [
                        "#main/mask_representative_sequences/masked_aligned_rep_seqs"
                    ],
                    "id": "#main/mask_representative_sequences"
                },
                {
                    "run": "#phylogeny-midpoint-root.cwl",
                    "in": [
                        {
                            "source": "#main/rooted_tree_filename",
                            "id": "#main/root_tree/rooted_tree_filename"
                        },
                        {
                            "source": "#main/create_tree_from_alignment/unrooted_tree",
                            "id": "#main/root_tree/tree"
                        }
                    ],
                    "out": [
                        "#main/root_tree/rooted_tree"
                    ],
                    "id": "#main/root_tree"
                }
            ],
            "id": "#main"
        }
    ],
    "cwlVersion": "v1.0"
}
